.. AUTO-GENERATED FILE -- DO NOT EDIT!

eventloop.stack_context
=======================

Module: :mod:`eventloop.stack_context`
--------------------------------------
.. automodule:: zmq.eventloop.stack_context

.. currentmodule:: zmq.eventloop.stack_context

Functions
---------


.. autofunction:: zmq.eventloop.stack_context.NullContext


.. autofunction:: zmq.eventloop.stack_context.StackContext


.. autofunction:: zmq.eventloop.stack_context.wrap

